package gs

import scala.util.Failure
import scala.util.Success
import scala.util.Try

sealed abstract class ReleaseType(val name: String)

object ReleaseType {
  case object Major extends ReleaseType("major")
  case object Minor extends ReleaseType("minor")
  case object Patch extends ReleaseType("patch")

  def parse(candidate: String): Try[ReleaseType] =
    candidate.trim().toLowerCase() match {
      case Major.name => Success(Major)
      case Minor.name => Success(Minor)
      case Patch.name => Success(Patch)
      case _ =>
        Failure(
          new IllegalArgumentException(s"Invalid release type: '$candidate'")
        )
    }

}
